@@ -1,3 +1,9 @@
+-- SchemaCrawler
+-- http://www.schemacrawler.com
+-- Copyright (c) 2000-2025, Sualeh Fatehi <sualeh@hotmail.com>.
+-- All rights reserved.
+-- SPDX-License-Identifier: EPL-2.0
+
 SELECT
   NULL AS TABLE_CAT,
   INDEXES.OWNER AS TABLE_SCHEM,
@@ -25,8 +31,10 @@ FROM
       AND USERS.ORACLE_MAINTAINED = 'N'
       AND NOT REGEXP_LIKE(USERS.USERNAME, '^APEX_[0-9]{6}$')
       AND NOT REGEXP_LIKE(USERS.USERNAME, '^FLOWS_[0-9]{5}$')
+      AND NOT REGEXP_LIKE(USERS.USERNAME, '^OPS\$ORACLE$')
 WHERE
-  REGEXP_LIKE(INDEXES.OWNER, '${schemas}')
+  REGEXP_LIKE(INDEXES.OWNER, '${schema-inclusion-rule}')
+  AND REGEXP_LIKE(INDEXES.OWNER || '.' || INDEXES.TABLE_NAME, '${table-inclusion-rule}')
   AND INDEXES.TABLE_NAME NOT LIKE 'BIN$%'
   AND NOT REGEXP_LIKE(INDEXES.TABLE_NAME, '^(SYS_IOT|MDOS|MDRS|MDRT|MDOT|MDXT)_.*$')
 ORDER BY
